@@ -1,22 +1,23 @@
 % QARTS   Defines setting fields for arts calculations
 %
-%    The function defines all Qarts fields. All fields are initiated to {}, that
-%    indicates that no value has been specified. No data will be transfered to
-%    arts for fields later not given a non-{} value. The settings are converted
-%    tocontrol files by *qarts2cfile*. This function adds automatically method
-%    calls for saving (standard) variables. everything else must be specified by
-%    the qarts fields or be handled by include control files.
-%
-%    Allowed formats differ between the fields. For information about a specific
-%    field, type e.g.:
-%       qinfo( @qarts, 'ABSORPTION' );
+%    The function defines all Qarts fields. All fields are initiated to {},
+%    that indicates that no value has been specified. No data will be
+%    transferred to arts for fields later not given a non-{} value. The
+%    settings are converted to control files by *qarts2cfile*. This function
+%    adds automatically method calls for saving (standard) variables.
+%    everything else must be specified by the qarts fields or be handled by
+%    include control files.
 %
 %    This function is organised in such way that *qcheck* and *qinfo* can be
 %    used.
 %
+%    Allowed formats differ between the fields. For information about a
+%    specific field, type e.g.:
+%       qinfo( @qarts, 'ABSORPTION' );
+%
 % FORMAT   [Q,I] = qarts
 %        
-% OUT   Q  Setting structure with default values for all recognised fields.
+% OUT   Q  Setting structure (with all fields set to {}).
 %       I  Includes same fields as Q, where the content of each field
 %          is a description string (used by *qinfo*).
 
@@ -36,14 +37,15 @@ I.ABSORPTION = [ ...
 'point. The agenda *abs_scalar_gas_agenda* must here be set by an include ',...
 'file. No other absorption variables need to be set.',...
 '#   ''CalcTable'': Calculate and use an absorption look-up table. See ',...
-'*qarts_set_abs_lookup* for simple setting of needed variables.',...
+'*qarts_abstable* for simple setting of needed variables.',...
 '#   ''LoadTable'': Load and use pre-calculated absorption look-up table, ',...
 'defined by field *ABS_LOOKUP*.',
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_LINES = {};
 I.ABS_LINES = [ ...
-'The data on spectroscopic lines to use. Can be given in two ways:', ...
+'The data on spectroscopic lines to use. See *ABS_LINES_FORMAT* for how ',...
+'to handle cases without lines. Can be given in two ways:', ...
 '#1. As a file name. All formats handled by arts can then be used. See', ...
 ' ABS_LINES_FORMAT. The reading is not restricted to any frequency range.', ...
 '#2. As an array of line data. This option is only allowed when ',...
@@ -95,7 +97,7 @@ I.ABS_MODELS = [ ...
 '*abs_cont_descriptionAppend* (call of *abs_cont_descriptionInit* shall ',...
 'be included).',...
 '#   Given as an array of strings. The atmlab setting ARTS_INCLUDES is ',...
-'recognized. A file containing standard choices is: ',...
+'recognised. A file containing standard choices is: ',...
 'ARTS_INCLUDES/continua.arts'
 ];
 %-----------------------------------------------------------------------------
@@ -161,9 +163,28 @@ I.ABS_SPECIES = [ ...
 'will be included in the L2 output. Otherwise not. This field has no ',...
 'importance if RETRIEVE is false.',...
 '# ',...
-'#Only the field TAG must be present if no retrievals are performed. The ',...
-'fields UNIT, GRIDS, SX and L2 can be left undefined if the species is not ',...
-'retrieved.'
+'#<L2_RANGE> Fine tuning of L2 data ranges. ',...
+'The default is to store data directly matching the retrieval ',...
+'grids. This is done if the field is non-existing. This ',...
+'field allows you to either crop or extend range of the L2 data. ',...
+'It is then a vector of length, at least, twice the atmospheric ',...
+'dimensionality: [p_min p_max lat_min lat_max lon_min lon_max] where ',...
+'lat_min gives the minimum latitude to include etc. ',...
+'# If a given limit is inside the range covered by the corresponding ',...
+'retrieval grid, this results in that the data are cropped. This ',...
+'feature can be used to remove parts that are of no interest for ',...
+'L2 data (such as parts always having a low measurement response). ',...
+'# The default L2 output is not reflecting the fact that values at ',...
+'end points of the retrieval grids are valid all the way to the ',...
+'matching atmospheric limit. This field can also be used to ',...
+'incorporate this part. If a limit is outside the retrieval grid, ',...
+'the L2 data will also include the retrieved state at the ',...
+'specified or the atmospheric limit (which is the closest to the ',...
+'retrieval grid). In practice this signifies a duplication of end point ',...
+'data.',...
+'# Only retrieved profile and errors are modified. Averaging kernel, ',...
+'covariance and gain matrices are kept consistent with the original ',...
+'retrieval grids.'
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_T = {};
@@ -193,6 +214,11 @@ I.ABS_VMRS = [ ...
 'Matlab variable.'
 ];
 %-----------------------------------------------------------------------------
+Q.ABS_WSMS = {};
+I.ABS_WSMS = [ ...
+'Workspace method calls to include just before calculation of absorption.'
+];
+%-----------------------------------------------------------------------------
 Q.ANTENNA_DIM = {};
 I.ANTENNA_DIM = [ ...
 'As the arts WSV with the same name.', ...
@@ -246,7 +272,7 @@ I.FFIT = [ ...
 'made if field is empty or sub-field RETRIEVAL is set to false. The WSM ',...
 'used is *jacobianAddFreqShiftAndStretch*. These sub-fields are defined:',...
 '# ',...
-'#<RETRIEVE> Flag to activate frequency retrieval', ...    
+'#<RETRIEVE> Flag to activate frequency retrieval.', ...    
 '# ',...
 '#<DF> Size for numerical perturbation. See used WSM.', ...
 '# ',...
@@ -261,12 +287,32 @@ I.FFIT = [ ...
 'importance if RETRIEVE is false.'
 ];
 %-----------------------------------------------------------------------------
+Q.HSE = {};
+I.HSE = [ ...
+'Variables associated with hydrostatic equilibrium. A structure with the ',...
+'sub-fields:',...
+'# ',...
+'#<ON> Flag to enforce hydrostatic equilibrium. If true, the WSV *z_field*',... 
+'is recalculated by *z_fieldFromHSE* (note that a "first guess" *z_field* ',... 
+'must be provided).',...
+'# ',...
+'#<P> Pressure for reference point. Matches the WSV *p_hse*.',...
+'# ',...
+'#<ACCURACY> Calculation accuracy. Matches the WSV *z_hse_accuracy*.',...
+'# ',...
+'#If the field is unset, no action is taken. This equals to set Q.HSE.ON ',...
+'to false. Note the setting Q.T.HSE which controls the calculation of t-',...
+'jacobians. The two settings are treated as independent, but should ',...
+'be set to the same value (true/false). If the HSE is maintained during ',...
+'the iterations of a temperature retrieval is controled by THIS field.'
+];    
+%-----------------------------------------------------------------------------
 Q.INCLUDES = {};
 I.INCLUDES = [ ...
 'Paths to control files to be included. These files will be included ',...
 'at the top of the control file, only preceded by WSMS_AT_START. Given ',...
 'as an array of strings.',...
-'#   The atmlab setting ARTS_INCLUDES is recognized. To include the ',...
+'#   The atmlab setting ARTS_INCLUDES is recognised. To include the ',...
 'standard arts general definition file, select:',...
 '{''ARTS_INCLUDES/general.arts''}'
 ];
@@ -278,12 +324,7 @@ I.INPUT_FILE_FORMAT = [ ...
 'and ''double''. The binary option, that is default, should be most '...
 'efficient. Use ''double'' if you want to visually inspect the files ',...
 'generated. (The option ''float'' is not allowed, as this is not always '...
-'sufficient for frequerncy data.)'
-];
-%-----------------------------------------------------------------------------
-Q.IY_AUX_DO = {};
-I.IY_AUX_DO = [ ...
-'As the arts WSV with the same name.'
+'sufficient for frequency data.)'
 ];
 %-----------------------------------------------------------------------------
 Q.IY_CLEARSKY_AGENDA = {};
@@ -302,18 +343,12 @@ I.IY_SPACE_AGENDA = [ ...
 Q.J_DO = {};
 I.J_DO = [ ...
 'Boolean to include calculation of jacobians.',...
-'#   {}: NOthing is done. Relevant data are assumed to be specified by ',...
+'#   {}: Nothing is done. Relevant data are assumed to be specified by ',...
 'inclusion files.',...
 '#    0: Call of *jacobianOff* is included.',...
 '#    1: Action follows setting of field *J*.'
 ];
 %-----------------------------------------------------------------------------
-Q.J_UNIT = {};
-I.J_UNIT = [ ...
-'Matches the WSV *jacobian_unit*. For further information: arts -d ',...
-'jacobian_unit'
-];
-%-----------------------------------------------------------------------------
 Q.LAT_GRID = {};
 I.LAT_GRID = [ ...
 'Has the same functionality as the arts WSV with the same name, with the ', ...
@@ -405,7 +440,7 @@ I.POLYFIT = [ ...
 '#<ORDER> Order of polynomial fit.', ...
 '# ',...
 '#<SX0> Covariance matrix of a priori knowledge for coefficient of order ',...
-'zero. There shall be sucha matrix for each cefficient order until:',...
+'zero. There shall be such a matrix for each coefficient order until:',...
 '# ',...
 '#<SXn> Covariance matrix of a priori knowledge for coefficient of order ',...
 'POLY_ORDER. The last required covariance matrix.',...
@@ -432,7 +467,7 @@ I.PPATH_LRAYTRACE = [ ...
 %-----------------------------------------------------------------------------
 Q.PPATH_STEP_AGENDA = {};
 I.PPATH_STEP_AGENDA = [ ...
-'As the arts WSV with the same name .', ...
+'As the arts WSV with the same name.', ...
 'WSMs are listed as an array of strings. ', ...
 'An example showing how an agenda definition looks like:', ...
 '#   Q.PPATH_STEP_AGENDA={''ppath_stepGeometric''}' 
@@ -447,23 +482,23 @@ I.P_GRID = [ ...
 %-----------------------------------------------------------------------------
 Q.R_GEOID = {};
 I.R_GEOID = [ ...
-'Geoid radius. A spherical geoid will be assumed if the field value is a ',...
-'a scalar. Otherwise it is assumed that the field holds a matrix of ', ...
-'correct size. Note that *wgs84* is part of atmlab and can be used to set ',...
-'the field value (e.g. Q.R_GEOID=wgs84(2.Q.LAT_GRID);).'
+'Geoid radius. As the arts WSV with the same name .'
 ];
 %-----------------------------------------------------------------------------
 Q.RAW_ATMOSPHERE = {};
 I.RAW_ATMOSPHERE = [ ...
-'Main file name for a raw atmosphere. See further ''arts -d AtmRawRead''. ',...
-'This variable is only used if USE_RAW_ATMOSPHERE = 1, but must then be set.'
+'If set a "raw atmosphere" in read. This is the main file name for the ',...
+'raw atmosphere. See further ''arts -d AtmRawRead''. ',...
+'#Data in the fields T_FIELD, Z_FIELD or VMR_FIELD are included at a later ',...
+'stage and will then overwrite the data from the raw atmosphere. This ',...
+'thus some flexibility to mix data from different sources.'
 ];
 %-----------------------------------------------------------------------------
 Q.RAW_ATM_EXPAND_1D = {};
 I.RAW_ATM_EXPAND_1D = [ ...
 'Boolean to expand an 1D raw atmosphere to set ATMOSPHERE_DIM. If set to ',...
 ' 1, the WSM *AtmFieldsCalcExpand1D* is used instead of *AtmFieldsCalc*.',...
-'This variable is only used if USE_RAW_ATMOSPHERE = 1, but must then be set.'
+'This variable is only used if RAW_ATMOSPHERE is set.'
 ];
 %-----------------------------------------------------------------------------
 Q.REFR_INDEX_AGENDA = {};
@@ -479,7 +514,7 @@ Q.SENSOR_DO = {};
 I.SENSOR_DO = [ ...
 'Boolean to include sensor characteristics. Otherwise monochromatic pencil ',...
 'beam calculations are performed. *SENSOR_POS/LOS* are used in both cases. ',...
-'#   {}: NOthing is done. Relevant data are assumed to be specified by ',...
+'#   {}: Nothing is done. Relevant data are assumed to be specified by ',...
 'inclusion files.',...
 '#    0: Call of *sensorOff* is included.',...
 '#    1: Action follows setting of field *SENSOR_RESPONSE*.'
@@ -588,18 +623,52 @@ I.SURFACE_PROP_AGENDA = [ ...
 ' See PPATH_STEP_AGENDA for a practical example on format to use.' 
 ];
 %-----------------------------------------------------------------------------
-Q.T_ATMDATA = {};
-I.T_ATMDATA = [ ...
-'The input shall follow the atmdata format, defined in *isatmdata*. The ',...
-'data specified here are not directly given to arts, it can only be used ',...
-'to set-up *T_FIELD*. This step is handled by *qarts_t_or_z_field*. ',...
-'The main usage of this field should be to import data of climatology ',...
-'character. Can be given as a variable or a file saved through *gf_save*.'
-];
+Q.T = {};
+I.T = [ ...
+'Data and setting associated with atmospheric temperatures. Normally used ',...
+'when retrieving temperature. Otherwise, *T_FIELD* can be set directly.',...
+'# ',...
+'#<ATMDATA> The input shall follow the atmdata format, defined in ',...
+'*isatmdata*. The data specified here are not directly given to arts, it ',...
+'can only be used to set-up *T_FIELD*. This step is handled by ',...
+'*qarts_t_or_z_field*. The main usage of this field should be to import ',...
+'data of climatology character. Can be given as a variable or a file saved ',...
+'through *gf_save*.',...
+'# ',...
+'#<RETRIEVE> If set to true, atmospheric temperatures are retrieved.', ...
+'# ',...
+'#<GRIDS> Retrieval grids for temperature. An array of vectors of length 3:',...
+' {p_grid,lat_grid,lon_grid}. Grids for dimensions not used shall be ',...
+'empty.',...
+'# ',...
+'#<SX> Covariance matrix of a priori knowledge for temperature. Size must ',...
+'match the grid field. Data must match <UNIT>. A matrix, that can be ',...
+'sparse.',...
+'# ',...
+'#<L2> Flag for any function creating L2 data. See comments for ',...
+'*L2_EXTRA*. If set to true, the retrieved state for temperature ',...
+'will be included in the L2 output. Otherwise not.',...
+'# ',...
+'#<L2_RANGE>  As the same field for ABS_SPECIES.',...
+'# ',...
+'#<HSE> As the argument to *jacobianAddTemperature* with same name. ',...
+'Default here is "on". This refers only to the actual jacobian calculation.',...
+' If the atmosphere itself fulfils HSE or not is controled by Q.HSE.',...
+'# ',...
+'#<METHOD> As the argument to *jacobianAddTemperature* with same name. ',...
+'Default here is "analytical".',...
+'# ',...
+'#<DT> As the argument to *jacobianAddTemperature* with same name. ',...
+'Default here is 1 K.',...
+'# ',...
+'#None of the fields are mandatory for pure forward calculations. If ',...
+'RETRIEVAL is set to false, the other retrieval related fields are ignored.'
+];  
 %-----------------------------------------------------------------------------
 Q.T_FIELD = {};
 I.T_FIELD = [ ...
-'As the arts WSV with the same name.', ...
+'As the arts WSV with the same name. Will replace temperature data inserted',...
+' through RAW_ATMOSPHERE.', ...
 '#   Can be given either as the name of a XML file, or as a matching ',...
 'Matlab variable.'
 ];
@@ -613,21 +682,37 @@ I.TNOISE_C = [ ...
 's*s*TNOISE_C.'
 ];
 %-----------------------------------------------------------------------------
-Q.USE_RAW_ATMOSPHERE = {};
-I.USE_RAW_ATMOSPHERE = [ ...
-'Boolean to decide if T_FIELD, Z_FIELD and VMR_FIELD shall be used', ...
-' (option 0) or RAW_ATMOSPHERE (option 1).'
-];
-%-----------------------------------------------------------------------------
 Q.VMR_FIELD = {};
 I.VMR_FIELD = [ ...
-'As the arts WSV with the same name.', ...
+'As the arts WSV with the same name. Will replace VMR data inserted ',...
+'through RAW_ATMOSPHERE.', ...
 '#   Can be given either as the name of a XML file, or as a matching ',...
 'Matlab variable.',...
 '#   For retrievals, the a priori state for *ABS_SPECIES* is determined ',...
 'by this field.'
 ];
 %-----------------------------------------------------------------------------
+Q.WIND_U_FIELD = {};
+I.WIND_U_FIELD = [ ...
+'As the arts WSV with the same name. Can be set to [].', ...
+'#   Can be given either as the name of a XML file, or as a matching ',...
+'Matlab variable.'
+];
+%-----------------------------------------------------------------------------
+Q.WIND_V_FIELD = {};
+I.WIND_V_FIELD = [ ...
+'As the arts WSV with the same name. Can be set to [].', ...
+'#   Can be given either as the name of a XML file, or as a matching ',...
+'Matlab variable.'
+];
+%-----------------------------------------------------------------------------
+Q.WIND_W_FIELD = {};
+I.WIND_W_FIELD = [ ...
+'As the arts WSV with the same name. Can be set to [].', ...
+'#   Can be given either as the name of a XML file, or as a matching ',...
+'Matlab variable.'
+];
+%-----------------------------------------------------------------------------
 Q.WSMS_AT_END = {};
 I.WSMS_AT_END = [ ...
 'Workspace method calls to include at the far end of the control file. ',...
@@ -657,7 +742,7 @@ I.YCALC_WSMS = [ ...
 'The standard choice should be that this fields includes a call of *yCalc*.',... 
 ' There is no clear division between this field and *WSMS_BEFORE_RTE*, but ',...
 'for best flexibility this field should start with *yCalc* (or corresponding',...
-' method), followed by post-processing not hanlded by other fields.',...
+' method), followed by post-processing not handled by other fields.',...
 '#   Accordingly, this field is considered only if spectra are calculated ',...
 '(ignored for e.g. pure absorption calculations). Format as for WSMS_AT_START.'
 ];
@@ -685,15 +770,15 @@ I.Z_ATMDATA = [ ...
 %-----------------------------------------------------------------------------
 Q.Z_FIELD = {};
 I.Z_FIELD = [ ...
-'As the arts WSV with the same name.', ...
+'As the arts WSV with the same name. Will replace altitude data inserted ',...
+'through RAW_ATMOSPHERE.', ...
 '#   Can be given either as the name of a XML file, or as a matching ',...
 'Matlab variable.'
 ];
 %-----------------------------------------------------------------------------
 Q.Z_SURFACE = {};
 I.Z_SURFACE = [ ...
-'Surface altitude (above geoid). A constant altitude will be assumed if ',...
-'the field value is a scalar. Otherwise it is assumed that the field ',...
-'holds a matrix of correct size.'
+'Surface altitude (above reference ellispoid). As the arts WSV with the ',...
+'same name.'
 ];
 %-----------------------------------------------------------------------------
