@@ -30,7 +30,7 @@ end
 for i = 0:nvars-1
    [varname, scrap, scrap, natts] = netcdf.inqVar (ncid, i);
    svarname = genvarname(varname);
-   ret.(svarname) = netcdf.getVar (ncid, i);
+   ret.(svarname) = nc_read_varid(ncid,i);
    for j = 0:natts-1
        attname = netcdf.inqAttName (ncid, i, j);
        ret.attributes.(svarname).(genvarname(attname)) = ...
@@ -38,4 +38,30 @@ for i = 0:nvars-1
    end 
 end
 
-netcdf.close (ncid);
\ No newline at end of file
+if (which('netcdf.inqGrps'))
+	grpids = netcdf.inqGrps (ncid);
+	for gid = grpids
+    	ret = catstruct(ret, read_group(ncid, gid));
+	end
+else
+    warning('atmlab:loadncfile:groupsunsupported', ...
+        'This Matlab version does not support NetCDF groups.');
+end
+
+netcdf.close (ncid);
+
+
+function grp = read_group(ncid, gid)
+
+varids = netcdf.inqVarIDs(gid);
+grpname = genvarname(netcdf.inqGrpName(gid));
+for i = varids
+    [varname, scrap, scrap, natts] = netcdf.inqVar (gid, i);
+    svarname = genvarname(varname);
+    grp.(grpname).(svarname) = netcdf.getVar (gid, i);
+    for j = 0:natts-1
+        attname = netcdf.inqAttName (gid, i, j);
+        grp.(grpname).attributes.(svarname).(genvarname(attname)) = ...
+            netcdf.getAtt (gid, i, attname);
+    end
+end
