@@ -24,4 +24,11 @@ if ispc
   if ~isempty(i)
     user = user((i+1):end);
   end
-end
\ No newline at end of file
+end
+
+
+%- Remove any newline character
+%
+if user(end) == sprintf('\n')
+  user = user(1:end-1);
+end
